@@ -206,6 +206,9 @@ INVALIDKEYPAIRNAMETOOLONG = 'InvalidKeyPairNameTooLong'
 # 参数错误。
 INVALIDPARAMETER = 'InvalidParameter'
 
+# 最多指定一个参数。
+INVALIDPARAMETER_ATMOSTONE = 'InvalidParameter.AtMostOne'
+
 # DataDiskIds不应该传入RootDisk的Id。
 INVALIDPARAMETER_DATADISKIDCONTAINSROOTDISK = 'InvalidParameter.DataDiskIdContainsRootDisk'
 
@@ -308,6 +311,9 @@ INVALIDPARAMETERVALUE_DISASTERRECOVERGROUPIDMALFORMED = 'InvalidParameterValue.D
 # 参数值重复。
 INVALIDPARAMETERVALUE_DUPLICATE = 'InvalidParameterValue.Duplicate'
 
+# 重复标签。
+INVALIDPARAMETERVALUE_DUPLICATETAGS = 'InvalidParameterValue.DuplicateTags'
+
 # 非GPU实例不允许转为GPU实例。
 INVALIDPARAMETERVALUE_GPUINSTANCEFAMILY = 'InvalidParameterValue.GPUInstanceFamily'
 
@@ -464,6 +470,9 @@ INVALIDPARAMETERVALUE_SUBNETNOTEXIST = 'InvalidParameterValue.SubnetNotExist'
 # 指定的标签不存在。
 INVALIDPARAMETERVALUE_TAGKEYNOTFOUND = 'InvalidParameterValue.TagKeyNotFound'
 
+# 标签配额超限。
+INVALIDPARAMETERVALUE_TAGQUOTALIMITEXCEEDED = 'InvalidParameterValue.TagQuotaLimitExceeded'
+
 # 每核心线程数不合法。
 INVALIDPARAMETERVALUE_THREADPERCOREVALUE = 'InvalidParameterValue.ThreadPerCoreValue'
 
@@ -569,6 +578,9 @@ LIMITEXCEEDED_SINGLEUSGQUOTA = 'LimitExceeded.SingleUSGQuota'
 # 竞价实例类型配额不足
 LIMITEXCEEDED_SPOTQUOTA = 'LimitExceeded.SpotQuota'
 
+# 标签绑定的资源数量已达到配额限制。
+LIMITEXCEEDED_TAGRESOURCEQUOTA = 'LimitExceeded.TagResourceQuota'
+
 # 退还失败，退还配额已达上限。
 LIMITEXCEEDED_USERRETURNQUOTA = 'LimitExceeded.UserReturnQuota'
 
@@ -632,6 +644,9 @@ RESOURCENOTFOUND_HPCCLUSTER = 'ResourceNotFound.HpcCluster'
 # 指定的置放群组不存在。
 RESOURCENOTFOUND_INVALIDPLACEMENTSET = 'ResourceNotFound.InvalidPlacementSet'
 
+# 可用区不支持此机型。
+RESOURCENOTFOUND_INVALIDZONEINSTANCETYPE = 'ResourceNotFound.InvalidZoneInstanceType'
+
 # 无可用的缺省类型的CBS资源。
 RESOURCENOTFOUND_NODEFAULTCBS = 'ResourceNotFound.NoDefaultCbs'
 
@@ -833,6 +848,9 @@ UNSUPPORTEDOPERATION_SHAREDIMAGEEXPORTUNSUPPORTED = 'UnsupportedOperation.Shared
 # 请求不支持特殊机型的实例
 UNSUPPORTEDOPERATION_SPECIALINSTANCETYPE = 'UnsupportedOperation.SpecialInstanceType'
 
+# 该地域不支持竞价实例。
+UNSUPPORTEDOPERATION_SPOTUNSUPPORTEDREGION = 'UnsupportedOperation.SpotUnsupportedRegion'
+
 # 不支持关机不收费特性
 UNSUPPORTEDOPERATION_STOPPEDMODESTOPCHARGING = 'UnsupportedOperation.StoppedModeStopCharging'
 
